/**************************************************************** 
 * Description: 2021 CSP-J 复赛第四题目 链表的方式
 * Author: Alex Li
 * Date: 2024-08-05 20:44:27
 * LastEditTime: 2024-08-05 22:53:13
****************************************************************/
#include <iostream>
#include <cstdio>
#include <vector>

using namespace std;

const int MAXN = 2e5+10; // 定义最大水果数量

struct Node {
    int prev; // 前一个节点的索引
    int val;  // 当前节点的值
    int next; // 后一个节点的索引
};

int n; // 水果数量

int fruit[MAXN]; // 用于存储每个水果的种类
Node headList[MAXN]; // 用于存储块的头节点, val 字段表示水果的位置
Node fruitList[MAXN]; // 用于存储所有水果的双向链表节点,val表示块的头位置。
int cc; // 用于记录当前块的数量

// 函数用于取出一个水果
void EatOne(int pos) { //pos=position 位置
    int prev = fruitList[pos].prev;
    int next = fruitList[pos].next;
    fruitList[prev].next = next; // 更新前一个节点的 next 指向
    fruitList[next].prev = prev; // 更新后一个节点的 prev 指向
    cout<<pos<<' '; // 打印当前取出的水果位置
}

// 函数用于删除一个块的头节点
void Del(int pos) {
    int prev = headList[pos].prev;
    int next = headList[pos].next;
    headList[prev].next = next; // 更新前一个头节点的 next 指向
    headList[next].prev = prev; // 更新后一个头节点的 prev 指向
}

// 主函数用于处理每次取水果操作
void getFruit() {
    int solo = headList[0].next; // 从第一个块开始
    int nowcolor = fruit[headList[solo].val]; // 当前块的水果种类
    while (solo != cc + 1) { // 遍历所有块
        if (fruit[headList[solo].val] != nowcolor) { // 如果当前块的水果种类不同
            Del(solo); // 删除当前块的头节点
            solo = headList[solo].next; // 移动到下一个块
            continue;
        }
        EatOne(headList[solo].val); // 取出当前块的一个水果
        headList[solo].val = fruitList[headList[solo].val].next; // 更新块的头节点
        if (fruit[headList[solo].val] != nowcolor) { // 如果更新后的块的水果种类不同
            Del(solo); // 删除当前块的头节点
        }
        solo = headList[solo].next; // 移动到下一个块
        nowcolor ^= 1; // 切换水果种类（0 和 1 之间切换）
    }
    cout<<'\n'; // 打印换行
}

int main() {
    cin>>n; // 读取水果数量
    fruitList[0].next = 1; // 初始化双向链表的起点
    for (int i = 1; i <= n; i++) { //从1开始
        cin>>fruit[i]; // 读取每个水果的种类
        fruitList[i].prev = i - 1; // 初始化前一个节点的索引
        fruitList[i].next = i + 1; // 初始化后一个节点的索引
    }
    fruit[0] = 2; // 设置哨兵值
    fruit[n+1] = 2; // 设置哨兵值
    headList[0].next = 1; // 初始化头节点链表的起点
    for (int i = 1; i <= n; i++) {
        if (fruit[i] != fruit[i - 1]) { // 如果当前水果种类与前一个不同
            cc++; // 增加块的数量
            headList[cc].prev = cc - 1; // 初始化前一个块的索引
            headList[cc].next = cc + 1; // 初始化下一个块的索引
            headList[cc].val = i; // 初始化当前块的值
        }
    }
    while (fruitList[0].next != n + 1) { // 当还有水果未取出时
        getFruit(); // 进行一次取水果操作
    }
    return 0;
}
